<?php
/**
 * Publications Model for Publications Component
 *
 * @package    Publications
 * components/com_publications/publications.php
 * @link http://www.icsr.agh.edu.pl/~polak/skrypty/publications.var
 * @license    GNU/GPL
 */

// No direct access to this file
defined('_JEXEC') or die('Restricted access');
 
/**
 * Publications Model
 *
 */
class PublicationsModelPublications extends JModelItem
{
	public $_total = null;
	public $_pagination = null;

	/*
	*In constructor we set pagination parameters
	*/
	function __construct() {
       
      		parent::__construct(); 

    		$application = JFactory::getApplication() ; 

    		$config = JFactory::getConfig() ; 

        	$limitstart = JRequest::getInt( 'limitstart', 0 );
    		$limit = $application->getUserStateFromRequest( 'global.list.limit', 'limit', $config->get('list_limit'), 'int' );        
    		$this->setState('limitstart', $limitstart); 
    		$this->setState('limit', $limit); 
	}
 
	/*
   	* @return the id of category of publications - the name (title) of this category is in a config file 
	*/
	public function getCategoryId()
	{
		//get a value of the $publications_title variable from a config file
               	require(JPATH_COMPONENT_ADMINISTRATOR.DIRECTORY_SEPARATOR.'publications_settings.php');
               	$db    = JFactory::getDBO();
               	$query = $db->getQuery(true);
               	$query->select('*')
                 	->from('#__categories')
                    	->where($db->quoteName('title')." = ".$db->quote($publications_title));
               	$db->setQuery($query);
		return $db->loadResult();
	}

	/*
	 * Loads publications from database
   	 * @return Array of objects containing publications
	 */
	public function _loadData() {
		//get a value of the $publications_title variable from a config file
                require(JPATH_COMPONENT_ADMINISTRATOR.DIRECTORY_SEPARATOR.'publications_settings.php');
                $db    = JFactory::getDBO();
                $query = $db->getQuery(true);
                $categoryId = $this->getCategoryId();
                $query->select('*')
                        ->from('#__content')
                        ->where($db->quoteName('catid')." = ".$db->quote($categoryId))
                        ->order('title DESC');
                $db->setQuery($query);
                $data = $db->loadObjectList();
        	$this->_total = count( $data ) ; 
		return $data;
	}

	/*
	 * @return publications for all or for selected years 
	 */	
	public function getYears() {
		$data = $this->_loadData();
		$limitstart = $this->getState('limitstart');
    		$limit = $this->getState('limit');
		if($limit >0)
       			return array_slice( $data, $limitstart, $limit ); 
		else
       			return $data; 
	}

	/*
	 * Creation of a pagination object 
	 */
	public function getPagination() 
	{ 
        	$data = $this->_loadData();

    		if (empty($this->_pagination)) 
    		{ 
        		jimport('joomla.html.pagination'); 

        		$limitstart = $this->getState('limitstart');
        		$limit = $this->getState('limit');
        		$total = $this->_total;

        		$this->_pagination = new JPagination( $total, $limitstart, $limit ); 
    		} 

		return $this->_pagination; 
	}


	/**
   	* Retrieves the publications
   	* @return Array of objects containing publications
   	*/
	public function getSearch()
        {
		//get a value of the $publications_title variable from a config file
                require(JPATH_COMPONENT_ADMINISTRATOR.DIRECTORY_SEPARATOR.'publications_settings.php');
		$categoryId = $this->getCategoryId();
		$db    = JFactory::getDBO();
                $query = $db->getQuery(true);

		//determine if all publications should be searched or  publications for selected year only
		$year   = JFactory::getApplication()->input->get('year');
		$order  = JFactory::getApplication()->input->get('order');
		if(strcmp("$year",'all')){
      			//get items published in $year
			$query->select('*')
				->from('#__content')	
				->where($db->quoteName('catid')." = ".$db->quote($categoryId, 'and')) 
				->where($db->quoteName('title')." = ".$db->quote($year)); 
		}
		else {
			$query->select('*')
				->from('#__content')
				->where($db->quoteName('catid')." = ".$db->quote($categoryId)) 
				->order('title '.$order);
		}
		$db->setQuery($query);
                return $db->loadObjectList();
	}	





}
